aboutsummaryrefslogtreecommitdiffstats
path: root/asn1/spnego
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2014-09-16 11:25:17 -0400
committerBill Meier <wmeier@newsguy.com>2014-09-16 15:31:58 +0000
commita379ac74d27a094cd89b0fc0f5196c46052f5a9f (patch)
tree662a038427bf7c82167703e4a3838a87dda0400b /asn1/spnego
parentb14bf98c06dbf1324c63dee633a025d251391601 (diff)
Fix spelling: cant-->can't, wont-->won't, etc
Change-Id: Ia6c3e7a25615bf8e052c3bacf096d76df775c9c2 Reviewed-on: https://code.wireshark.org/review/4126 Reviewed-by: Bill Meier <wmeier@newsguy.com>
Diffstat (limited to 'asn1/spnego')
-rw-r--r--asn1/spnego/packet-spnego-template.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/asn1/spnego/packet-spnego-template.c b/asn1/spnego/packet-spnego-template.c
index f0f80789ca..bdd0fdc365 100644
--- a/asn1/spnego/packet-spnego-template.c
+++ b/asn1/spnego/packet-spnego-template.c
@@ -544,7 +544,7 @@ decrypt_arcfour(packet_info *pinfo,
datalen -= padlen;
}
/* dont know what the checksum looks like for dce style gssapi */
if(pinfo->decrypt_gssapi_tvb==DECRYPT_GSSAPI_NORMAL){
ret = arcfour_mic_cksum(key_value, key_size,
KRB5_KU_USAGE_SEAL,
@@ -584,7 +584,7 @@ decrypt_gssapi_krb_arcfour_wrap(proto_tree *tree _U_, packet_info *pinfo, tvbuff
length=tvb_captured_length(pinfo->gssapi_encrypted_tvb);
original_data=tvb_get_ptr(pinfo->gssapi_encrypted_tvb, 0, length);
/* dont do anything if we are not attempting to decrypt data */
/*
if(!krb_decrypt){
return;
@@ -694,7 +694,7 @@ decrypt_gssapi_krb_cfx_wrap(proto_tree *tree _U_,
int datalen;
tvbuff_t *next_tvb;
/* dont do anything if we are not attempting to decrypt data */
if(!krb_decrypt){
return;
}
@@ -831,7 +831,7 @@ dissect_spnego_krb5_wrap_base(tvbuff_t *tvb, int offset, packet_info *pinfo
len=tvb_reported_length_remaining(tvb,offset);
if(len>tvb_captured_length_remaining(tvb, offset)){
/* no point in trying to decrypt,
- we dont have the full pdu.
+ we don't have the full pdu.
*/
return offset;
}
@@ -1074,7 +1074,7 @@ dissect_spnego_krb5_cfx_wrap_base(tvbuff_t *tvb, int offset, packet_info *pinfo
len=tvb_reported_length_remaining(tvb,offset);
if(len>tvb_captured_length_remaining(tvb, offset)){
/* no point in trying to decrypt,
- we dont have the full pdu.
+ we don't have the full pdu.
*/
return offset;
}
@@ -544,7 +544,7 @@ decrypt_arcfour(packet_info *pinfo,
datalen -= padlen;
}
- /* dont know what the checksum looks like for dce style gssapi */
+ /* don't know what the checksum looks like for dce style gssapi */
if(pinfo->decrypt_gssapi_tvb==DECRYPT_GSSAPI_NORMAL){
ret = arcfour_mic_cksum(key_value, key_size,
@@ -584,7 +584,7 @@ decrypt_gssapi_krb_arcfour_wrap(proto_tree *tree _U_, packet_info *pinfo, tvbuff
length=tvb_captured_length(pinfo->gssapi_encrypted_tvb);
original_data=tvb_get_ptr(pinfo->gssapi_encrypted_tvb, 0, length);
- /* dont do anything if we are not attempting to decrypt data */
+ /* don't do anything if we are not attempting to decrypt data */
/*
if(!krb_decrypt){
@@ -694,7 +694,7 @@ decrypt_gssapi_krb_cfx_wrap(proto_tree *tree _U_,
int datalen;
tvbuff_t *next_tvb;
- /* dont do anything if we are not attempting to decrypt data */
+ /* don't do anything if we are not attempting to decrypt data */
if(!krb_decrypt){
return;